@@ -39,8 +39,8 @@ class GUI_EXPORT QgsCodeEditor : public QsciScintilla
      *
      * @param parent The parent QWidget
      * @param title The title to show in the code editor dialog
-     * @param folding False: Enable margin for code editor
-     * @param margin False: Enable folding for code editor
+     * @param folding false: Enable folding for code editor
+     * @param margin false: Enable margin for code editor
      * @note added in 2.6
      */
     QgsCodeEditor( QWidget *parent = nullptr, const QString& title = "", bool folding = false, bool margin = false );
@@ -73,6 +73,9 @@ class GUI_EXPORT QgsCodeEditor : public QsciScintilla
 
     bool isFixedPitch( const QFont& font );
 
+    void focusOutEvent( QFocusEvent *event ) override;
+    void keyPressEvent( QKeyEvent * event ) override;
+
     QFont getMonospaceFont();
 
   private:
