@@ -20,6 +20,9 @@
 #include <QString>
 #include <QDomElement>
 
+/** \ingroup core
+ * \class QgsFontUtils
+ */
 class CORE_EXPORT QgsFontUtils
 {
   public:
@@ -49,7 +52,7 @@ class CORE_EXPORT QgsFontUtils
      * @param match Whether the family [foundry] returned by system is a match
      * @returns Whether family was found on system
      */
-    static bool fontFamilyMatchOnSystem( const QString& family, QString* chosen = 0, bool* match = 0 );
+    static bool fontFamilyMatchOnSystem( const QString& family, QString* chosen = nullptr, bool* match = nullptr );
 
     /** Updates font with named style and retain all font properties
      * @param f The font to update
@@ -129,6 +132,17 @@ class CORE_EXPORT QgsFontUtils
      * @see translateNamedStyle
      */
     static QString untranslateNamedStyle( const QString& namedStyle );
+
+    /** Returns a CSS string representing the specified font as closely as possible.
+     * @param font QFont to convert
+     * @param pointToPixelMultiplier scaling factor to apply to convert point sizes to pixel font sizes.
+     * The CSS returned by this function will always use pixels for font sizes, so this parameter
+     * should be set to a suitable value to convert point sizes to pixels (eg taking into account
+     * desination DPI)
+     * @returns partial CSS string, eg "font-family: Comic Sans; font-size: 12px;"
+     * @note added in QGIS 2.16
+     */
+    static QString asCSS( const QFont& font, double pointToPixelMultiplier = 1.0 );
 };
 
 #endif // QGSFONTUTILS_H
