@@ -27,6 +27,7 @@ class QgsLayerTreeGroup;
 class QgsLayerTreeNode;
 
 /**
+ * \ingroup gui
  * The QgsLayerTreeMapCanvasBridge class takes care of updates of layer set
  * for QgsMapCanvas from a layer tree. The class listens to the updates in the layer tree
  * and updates the list of layers for rendering whenever some layers are added, removed,
@@ -46,7 +47,7 @@ class GUI_EXPORT QgsLayerTreeMapCanvasBridge : public QObject
     Q_OBJECT
   public:
     //! Constructor: does not take ownership of the layer tree nor canvas
-    QgsLayerTreeMapCanvasBridge( QgsLayerTreeGroup* root, QgsMapCanvas* canvas, QObject* parent = 0 );
+    QgsLayerTreeMapCanvasBridge( QgsLayerTreeGroup* root, QgsMapCanvas* canvas, QObject* parent = nullptr );
 
     void clear();
 
