@@ -32,6 +32,9 @@ class QgsVertexMarker;
 class QgsMapLayer;
 class QgsGeometryValidator;
 
+/** \ingroup gui
+ * \class QgsMapToolCapture
+ */
 class GUI_EXPORT QgsMapToolCapture : public QgsMapToolAdvancedDigitizing
 {
     Q_OBJECT
@@ -189,7 +192,16 @@ class GUI_EXPORT QgsMapToolCapture : public QgsMapToolAdvancedDigitizing
      * List of digitized points
      * @return List of points
      */
-    QList<QgsPoint> points();
+    QList<QgsPoint> points() const;
+
+    /**
+     * List of digitized points with z support
+     *
+     * @return List of points
+     *
+     * @note added in 2.18
+     */
+    QgsPointSequenceV2 pointsV2();
 
     /**
      * Set the points on which to work
@@ -236,6 +248,8 @@ class GUI_EXPORT QgsMapToolCapture : public QgsMapToolAdvancedDigitizing
 
     QgsVertexMarker* mSnappingMarker;
 
+    friend class TestQgsMapToolReshape;
+
 #ifdef Q_OS_WIN
     int mSkipNextContextMenuEvent;
 #endif
