@@ -25,7 +25,7 @@ __copyright__ = '(C) 2015, Médéric Ribreux'
 
 __revision__ = '$Format:%H$'
 
-from v_net import variableOutput
+from .v_net import variableOutput
 
 
 def processOutputs(alg):
