@@ -116,7 +116,7 @@ class ExportGeometryInfo(GeoAlgorithm):
         outFeat.setFields(fields)
 
         features = vector.features(layer)
-        total = 100.0 / len(features)
+        total = 100.0 / len(features) if len(features) > 0 else 1
         for current, f in enumerate(features):
             inGeom = f.geometry()
 
