@@ -26,8 +26,9 @@ __copyright__ = '(C) 2012, Victor Olaya'
 __revision__ = '$Format:%H$'
 
 import os
+import json
 
-from PyQt4.QtGui import QIcon
+from qgis.PyQt.QtGui import QIcon
 
 from processing.core.GeoAlgorithm import GeoAlgorithm
 from processing.core.GeoAlgorithmExecutionException import GeoAlgorithmExecutionException
@@ -42,22 +43,30 @@ from processing.core.parameters import ParameterNumber
 from processing.core.parameters import ParameterBoolean
 from processing.core.parameters import ParameterSelection
 from processing.core.parameters import ParameterTableField
+from processing.core.parameters import ParameterTableMultipleField
 from processing.core.parameters import ParameterExtent
+from processing.core.parameters import ParameterCrs
 from processing.core.parameters import ParameterFile
+from processing.core.parameters import ParameterPoint
 from processing.core.outputs import OutputTable
 from processing.core.outputs import OutputVector
 from processing.core.outputs import OutputRaster
 from processing.core.outputs import OutputHTML
 from processing.core.outputs import OutputFile
+from processing.core.outputs import OutputDirectory
+from processing.core.outputs import OutputString
+from processing.core.outputs import OutputNumber
 from processing.tools.system import isWindows
+from processing.tools.system import setTempOutput
 from processing.script.WrongScriptException import WrongScriptException
-from RUtils import RUtils
+from .RUtils import RUtils
 
 
 class RAlgorithm(GeoAlgorithm):
 
     R_CONSOLE_OUTPUT = 'R_CONSOLE_OUTPUT'
     RPLOTS = 'RPLOTS'
+    R_OUTPUT_VALUES = 'R_OUTPUT_VALUES'
 
     def getCopy(self):
         newone = RAlgorithm(self.descriptionFile)
@@ -95,6 +104,7 @@ class RAlgorithm(GeoAlgorithm):
         self.commands = []
         self.showPlots = False
         self.showConsoleOutput = False
+        self.saveOutputValues = False
         self.useRasterPackage = True
         self.passFileNames = False
         self.verboseCommands = []
@@ -104,7 +114,7 @@ class RAlgorithm(GeoAlgorithm):
             if line.startswith('##'):
                 try:
                     self.processParameterLine(line)
-                except Exception:
+                except Exception as e:
                     raise WrongScriptException(
                         self.tr('Could not load R script: %s.\n Problem with line %s' % (self.descriptionFile, line)))
             elif line.startswith('>'):
@@ -149,74 +159,24 @@ class RAlgorithm(GeoAlgorithm):
         tokens = line.split('=')
         desc = self.createDescriptiveName(tokens[0])
         if tokens[1].lower().strip() == 'group':
-            self.group = tokens[0]
+            self.group = self.i18n_group = tokens[0]
             return
-        if tokens[1].lower().strip().startswith('raster'):
-            param = ParameterRaster(tokens[0], desc, False)
-        elif tokens[1].lower().strip() == 'vector':
-            param = ParameterVector(tokens[0], desc,
-                                    [ParameterVector.VECTOR_TYPE_ANY])
-        elif tokens[1].lower().strip() == 'vector point':
-            param = ParameterVector(tokens[0], desc,
-                                    [ParameterVector.VECTOR_TYPE_POINT])
-        elif tokens[1].lower().strip() == 'vector line':
-            param = ParameterVector(tokens[0], desc,
-                                    [ParameterVector.VECTOR_TYPE_LINE])
-        elif tokens[1].lower().strip() == 'vector polygon':
-            param = ParameterVector(tokens[0], desc,
-                                    [ParameterVector.VECTOR_TYPE_POLYGON])
-        elif tokens[1].lower().strip() == 'table':
-            param = ParameterTable(tokens[0], desc, False)
-        elif tokens[1].lower().strip().startswith('multiple raster'):
-            param = ParameterMultipleInput(tokens[0], desc,
-                                           ParameterMultipleInput.TYPE_RASTER)
-            param.optional = False
-        elif tokens[1].lower().strip() == 'multiple vector':
-            param = ParameterMultipleInput(tokens[0], desc,
-                                           ParameterMultipleInput.TYPE_VECTOR_ANY)
-            param.optional = False
-        elif tokens[1].lower().strip().startswith('selection'):
-            options = tokens[1].strip()[len('selection'):].split(';')
-            param = ParameterSelection(tokens[0], desc, options)
-        elif tokens[1].lower().strip().startswith('boolean'):
-            default = tokens[1].strip()[len('boolean') + 1:]
-            param = ParameterBoolean(tokens[0], desc, default)
-        elif tokens[1].lower().strip().startswith('number'):
-            try:
-                default = float(tokens[1].strip()[len('number') + 1:])
-                param = ParameterNumber(tokens[0], desc, default=default)
-            except:
-                raise WrongScriptException(
-                    self.tr('Could not load R script: %s.\n Problem with line %s' % (self.descriptionFile, line)))
-        elif tokens[1].lower().strip().startswith('field'):
-            field = tokens[1].strip()[len('field') + 1:]
-            found = False
-            for p in self.parameters:
-                if p.name == field:
-                    found = True
-                    break
-            if found:
-                param = ParameterTableField(tokens[0], tokens[0], field)
-        elif tokens[1].lower().strip() == 'extent':
-            param = ParameterExtent(tokens[0], desc)
-        elif tokens[1].lower().strip() == 'file':
-            param = ParameterFile(tokens[0], desc, False)
-        elif tokens[1].lower().strip() == 'folder':
-            param = ParameterFile(tokens[0], desc, True)
-        elif tokens[1].lower().strip().startswith('string'):
-            default = tokens[1].strip()[len('string') + 1:]
-            param = ParameterString(tokens[0], desc, default)
-        elif tokens[1].lower().strip().startswith('longstring'):
-            default = tokens[1].strip()[len('longstring') + 1:]
-            param = ParameterString(tokens[0], desc, default, multiline=True)
-        elif tokens[1].lower().strip().startswith('output raster'):
-            out = OutputRaster()
-        elif tokens[1].lower().strip().startswith('output vector'):
-            out = OutputVector()
-        elif tokens[1].lower().strip().startswith('output table'):
-            out = OutputTable()
-        elif tokens[1].lower().strip().startswith('output file'):
-            out = OutputFile()
+        if tokens[1].lower().strip() == 'name':
+            self.name = self.i18n_name = tokens[0]
+            return
+
+        if tokens[1].lower().strip().startswith('output'):
+            outToken = tokens[1].strip()[len('output') + 1:]
+            out = self.processOutputParameterToken(outToken)
+
+        elif tokens[1].lower().strip().startswith('optional'):
+            optToken = tokens[1].strip()[len('optional') + 1:]
+            param = self.processInputParameterToken(optToken, tokens[0])
+            if param:
+                param.optional = True
+
+        else:
+            param = self.processInputParameterToken(tokens[1], tokens[0])
 
         if param is not None:
             self.addParameter(param)
@@ -228,6 +188,127 @@ class RAlgorithm(GeoAlgorithm):
             raise WrongScriptException(
                 self.tr('Could not load R script: %s.\n Problem with line %s' % (self.descriptionFile, line)))
 
+    def processInputParameterToken(self, token, name):
+        param = None
+
+        desc = self.createDescriptiveName(name)
+
+        if token.lower().strip().startswith('raster'):
+            param = ParameterRaster(name, desc, False)
+        elif token.lower().strip() == 'vector':
+            param = ParameterVector(name, desc,
+                                    [ParameterVector.VECTOR_TYPE_ANY])
+        elif token.lower().strip() == 'vector point':
+            param = ParameterVector(name, desc,
+                                    [ParameterVector.VECTOR_TYPE_POINT])
+        elif token.lower().strip() == 'vector line':
+            param = ParameterVector(name, desc,
+                                    [ParameterVector.VECTOR_TYPE_LINE])
+        elif token.lower().strip() == 'vector polygon':
+            param = ParameterVector(name, desc,
+                                    [ParameterVector.VECTOR_TYPE_POLYGON])
+        elif token.lower().strip() == 'table':
+            param = ParameterTable(name, desc, False)
+        elif token.lower().strip().startswith('multiple raster'):
+            param = ParameterMultipleInput(name, desc,
+                                           ParameterMultipleInput.TYPE_RASTER)
+            param.optional = False
+        elif token.lower().strip() == 'multiple vector':
+            param = ParameterMultipleInput(name, desc,
+                                           ParameterMultipleInput.TYPE_VECTOR_ANY)
+            param.optional = False
+        elif token.lower().strip().startswith('selection'):
+            options = token.strip()[len('selection'):].split(';')
+            param = ParameterSelection(name, desc, options)
+        elif token.lower().strip().startswith('boolean'):
+            default = token.strip()[len('boolean') + 1:]
+            if default:
+                param = ParameterBoolean(name, desc, default)
+            else:
+                param = ParameterBoolean(name, desc)
+        elif token.lower().strip().startswith('number'):
+            default = token.strip()[len('number') + 1:]
+            if default:
+                param = ParameterNumber(name, desc, default=default)
+            else:
+                param = ParameterNumber(name, desc)
+        elif token.lower().strip().startswith('field'):
+            field = token.strip()[len('field') + 1:]
+            found = False
+            for p in self.parameters:
+                if p.name == field:
+                    found = True
+                    break
+            if found:
+                param = ParameterTableField(name, desc, field)
+        elif token.lower().strip().startswith('multiple field'):
+            field = token.strip()[len('multiple field') + 1:]
+            found = False
+            for p in self.parameters:
+                if p.name == field:
+                    found = True
+                    break
+            if found:
+                param = ParameterTableMultipleField(name, desc, field)
+        elif token.lower().strip() == 'extent':
+            param = ParameterExtent(name, desc)
+        elif token.lower().strip() == 'point':
+            param = ParameterPoint(name, desc)
+        elif token.lower().strip() == 'file':
+            param = ParameterFile(name, desc, False)
+        elif token.lower().strip() == 'folder':
+            param = ParameterFile(name, desc, True)
+        elif token.lower().strip().startswith('string'):
+            default = token.strip()[len('string') + 1:]
+            if default:
+                param = ParameterString(name, desc, default)
+            else:
+                param = ParameterString(name, desc)
+        elif token.lower().strip().startswith('longstring'):
+            default = token.strip()[len('longstring') + 1:]
+            if default:
+                param = ParameterString(name, desc, default, multiline=True)
+            else:
+                param = ParameterString(name, desc, multiline=True)
+        elif token.lower().strip() == 'crs':
+            default = token.strip()[len('crs') + 1:]
+            if default:
+                param = ParameterCrs(name, desc, default)
+            else:
+                param = ParameterCrs(name, desc)
+
+        return param
+
+    def processOutputParameterToken(self, token):
+        out = None
+
+        if token.lower().strip().startswith('raster'):
+            out = OutputRaster()
+        elif token.lower().strip().startswith('vector'):
+            out = OutputVector()
+        elif token.lower().strip().startswith('table'):
+            out = OutputTable()
+        else:
+            if token.lower().strip().startswith('file'):
+                out = OutputFile()
+                ext = token.strip()[len('file') + 1:]
+                if ext:
+                    out.ext = ext
+            elif token.lower().strip().startswith('directory'):
+                out = OutputDirectory()
+            elif token.lower().strip().startswith('number'):
+                out = OutputNumber()
+            elif token.lower().strip().startswith('string'):
+                out = OutputString()
+
+            if not self.saveOutputValues and out:
+                outVal = OutputFile(RAlgorithm.R_OUTPUT_VALUES, self.tr('R Output values'), ext='txt')
+                outVal.hidden = True
+                self.addOutput(outVal)
+                self.saveOutputValues = True
+
+        return out
+
     def processAlgorithm(self, progress):
         if isWindows():
             path = RUtils.RFolder()
@@ -242,6 +323,10 @@ class RAlgorithm(GeoAlgorithm):
             progress.setCommand(line)
         ProcessingLog.addToLog(ProcessingLog.LOG_INFO, loglines)
         RUtils.executeRAlgorithm(self, progress)
+        if self.saveOutputValues:
+            with open(self.getOutputValue(RAlgorithm.R_OUTPUT_VALUES), 'r') as f:
+                lines = [line.strip() for line in f]
+            self.parseOutputValues(iter(lines))
         if self.showPlots:
             htmlfilename = self.getOutputValue(RAlgorithm.RPLOTS)
             f = open(htmlfilename, 'w')
@@ -253,6 +338,37 @@ class RAlgorithm(GeoAlgorithm):
             f.write(RUtils.getConsoleOutput())
             f.close()
 
+    def parseOutputValues(self, lines):
+        if not self.saveOutputValues:
+            return
+
+        out = None
+        ender = 0
+        line = lines.next().strip('\n').strip('\r')
+        while ender < 10:
+            if line.startswith('##'):
+                name = line.replace('#', '')
+                out = self.getOutputFromName(name)
+            else:
+                if line == '':
+                    ender += 1
+                else:
+                    ender = 0
+                    if out:
+                        if isinstance(out, OutputNumber):
+                            out.setValue(float(line) if '.' in line else int(line))
+                        elif isinstance(out, OutputString):
+                            if not out.value:
+                                out.setValue(line)
+                            else:
+                                out.value += '\n\r' + line
+                        else:
+                            out.setValue(line)
+            try:
+                line = lines.next().strip('\n').strip('\r')
+            except:
+                break
+
     def getFullSetOfRCommands(self):
         commands = []
         commands += self.getImportCommands()
@@ -263,6 +379,15 @@ class RAlgorithm(GeoAlgorithm):
 
     def getExportCommands(self):
         commands = []
+
+        # Output Values
+        outputDataFile = None
+        if self.saveOutputValues:
+            outputDataFile = self.getOutputValue(RAlgorithm.R_OUTPUT_VALUES)
+            if not outputDataFile:
+                setTempOutput(self.getOutputFromName(RAlgorithm.R_OUTPUT_VALUES), self)
+                outputDataFile = self.getOutputValue(RAlgorithm.R_OUTPUT_VALUES)
+
         for out in self.outputs:
             if isinstance(out, OutputRaster):
                 value = out.value
@@ -275,7 +400,7 @@ class RAlgorithm(GeoAlgorithm):
                         value = value + '.tif'
                     commands.append('writeGDAL(' + out.name + ',"' + value
                                     + '")')
-            if isinstance(out, OutputVector):
+            elif isinstance(out, OutputVector):
                 value = out.value
                 if not value.endswith('shp'):
                     value = value + '.shp'
@@ -284,6 +409,13 @@ class RAlgorithm(GeoAlgorithm):
                 filename = filename[:-4]
                 commands.append('writeOGR(' + out.name + ',"' + value + '","'
                                 + filename + '", driver="ESRI Shapefile")')
+            elif isinstance(out, OutputTable):
+                value = out.value
+                value = value.replace('\\', '/')
+                commands.append('write.csv(' + out.name + ',"' + value + '")')
+            elif out.name != RAlgorithm.R_OUTPUT_VALUES and self.saveOutputValues:
+                commands.append('cat("##' + out.name + '",file="' + outputDataFile + '",sep="\n",append=TRUE)')
+                commands.append('cat(' + out.name + ',file="' + outputDataFile + '",sep="\n",append=TRUE)')
 
         if self.showPlots:
             commands.append('dev.off()')
@@ -308,44 +440,73 @@ class RAlgorithm(GeoAlgorithm):
         commands.append('library("raster")')
         commands.append('library("rgdal")')
 
+        # Add parameters
         for param in self.parameters:
             if isinstance(param, ParameterRaster):
-                value = param.value
-                value = value.replace('\\', '/')
-                if self.passFileNames:
-                    commands.append(param.name + ' = "' + value + '"')
-                elif self.useRasterPackage:
-                    commands.append(param.name + ' = ' + 'brick("' + value
-                                    + '")')
+                if param.value is None:
+                    commands.append(param.name + '= NULL')
                 else:
-                    commands.append(param.name + ' = ' + 'readGDAL("' + value
-                                    + '")')
-            if isinstance(param, ParameterVector):
-                value = param.getSafeExportedLayer()
-                value = value.replace('\\', '/')
-                filename = os.path.basename(value)
-                filename = filename[:-4]
-                folder = os.path.dirname(value)
-                if self.passFileNames:
-                    commands.append(param.name + ' = "' + value + '"')
+                    value = param.value
+                    value = value.replace('\\', '/')
+                    if self.passFileNames:
+                        commands.append(param.name + ' = "' + value + '"')
+                    elif self.useRasterPackage:
+                        commands.append(param.name + ' = ' + 'brick("' + value
+                                        + '")')
+                    else:
+                        commands.append(param.name + ' = ' + 'readGDAL("' + value
+                                        + '")')
+            elif isinstance(param, ParameterVector):
+                if param.value is None:
+                    commands.append(param.name + '= NULL')
                 else:
-                    commands.append(param.name + ' = readOGR("' + folder
-                                    + '",layer="' + filename + '")')
-            if isinstance(param, ParameterTable):
-                value = param.value
-                if not value.lower().endswith('csv'):
-                    raise GeoAlgorithmExecutionException(
-                        'Unsupported input file format.\n' + value)
-                if self.passFileNames:
-                    commands.append(param.name + ' = "' + value + '"')
+                    value = param.getSafeExportedLayer()
+                    value = value.replace('\\', '/')
+                    filename = os.path.basename(value)
+                    filename = filename[:-4]
+                    folder = os.path.dirname(value)
+                    if self.passFileNames:
+                        commands.append(param.name + ' = "' + value + '"')
+                    else:
+                        commands.append(param.name + ' = readOGR("' + folder
+                                        + '",layer="' + filename + '")')
+            elif isinstance(param, ParameterTable):
+                if param.value is None:
+                    commands.append(param.name + '= NULL')
                 else:
-                    commands.append(param.name + ' <- read.csv("' + value
-                                    + '", head=TRUE, sep=",")')
-            elif isinstance(param, (ParameterTableField, ParameterString,
+                    value = param.value
+                    if not value.lower().endswith('csv'):
+                        raise GeoAlgorithmExecutionException(
+                            'Unsupported input file format.\n' + value)
+                    if self.passFileNames:
+                        commands.append(param.name + ' = "' + value + '"')
+                    else:
+                        commands.append(param.name + ' <- read.csv("' + value
+                                        + '", head=TRUE, sep=",")')
+            elif isinstance(param, ParameterExtent):
+                if param.value:
+                    tokens = unicode(param.value).split(',')
+                    # Extent from raster package is "xmin, xmax, ymin, ymax" like in Processing
+                    # http://www.inside-r.org/packages/cran/raster/docs/Extent
+                    commands.append(param.name + ' = extent(' + tokens[0] + ',' + tokens[1] + ',' + tokens[2] + ',' + tokens[3] + ')')
+                else:
+                    commands.append(param.name + ' = NULL')
+            elif isinstance(param, ParameterCrs):
+                if param.value is None:
+                    commands.append(param.name + '= NULL')
+                else:
+                    commands.append(param.name + ' = "' + param.value + '"')
+            elif isinstance(param, (ParameterTableField, ParameterTableMultipleField, ParameterString,
                                     ParameterFile)):
-                commands.append(param.name + '="' + param.value + '"')
+                if param.value is None:
+                    commands.append(param.name + '= NULL')
+                else:
+                    commands.append(param.name + '="' + param.value + '"')
             elif isinstance(param, (ParameterNumber, ParameterSelection)):
-                commands.append(param.name + '=' + unicode(param.value))
+                if param.value is None:
+                    commands.append(param.name + '= NULL')
+                else:
+                    commands.append(param.name + '=' + unicode(param.value))
             elif isinstance(param, ParameterBoolean):
                 if param.value:
                     commands.append(param.name + '=TRUE')
@@ -398,6 +559,13 @@ class RAlgorithm(GeoAlgorithm):
                 s += ')\n'
                 commands.append(s)
 
+        # Set outputs
+        for out in self.outputs:
+            if isinstance(out, OutputFile) or isinstance(out, OutputDirectory):
+                if not out.value:
+                    setTempOutput(out, self)
+                commands.append(out.name + ' = "' + out.value + '"')
+
         if self.showPlots:
             htmlfilename = self.getOutputValue(RAlgorithm.RPLOTS)
             self.plotsFilename = htmlfilename + '.png'
@@ -416,6 +584,36 @@ class RAlgorithm(GeoAlgorithm):
         else:
             return False, None
 
+    def shortHelp(self):
+        if self.descriptionFile is None:
+            return None
+        helpFile = unicode(self.descriptionFile) + '.help'
+        if os.path.exists(helpFile):
+            with open(helpFile) as f:
+                try:
+                    descriptions = json.load(f)
+                    if 'ALG_DESC' in descriptions:
+                        return self._formatHelp(unicode(descriptions['ALG_DESC']))
+                except:
+                    return None
+        return None
+
+    def getParameterDescriptions(self):
+        descs = {}
+        if self.descriptionFile is None:
+            return descs
+        helpFile = unicode(self.descriptionFile) + '.help'
+        if os.path.exists(helpFile):
+            with open(helpFile) as f:
+                try:
+                    descriptions = json.load(f)
+                    for param in self.parameters:
+                        if param.name in descriptions:
+                            descs[param.name] = unicode(descriptions[param.name])
+                except:
+                    return descs
+        return descs
+
     def checkBeforeOpeningParametersDialog(self):
         msg = RUtils.checkRIsInstalled()
         if msg is not None:
