@@ -28,8 +28,7 @@ __revision__ = '$Format:%H$'
 import os
 
 from qgis.PyQt import uic
-from qgis.PyQt.QtCore import (Qt,
-                              QEvent)
+from qgis.PyQt.QtCore import Qt, QEvent, QSettings
 from qgis.PyQt.QtWidgets import (QFileDialog,
                                  QDialog,
                                  QStyle,
@@ -257,6 +256,8 @@ class ConfigDialog(BASE, WIDGET):
         for provider in providers:
             for alg in provider.algs:
                 d = defaultMenuEntries.get(alg.commandLineName(), "")
+                if "MENU_" + alg.commandLineName() not in ProcessingConfig.settings:
+                    continue
                 setting = ProcessingConfig.settings["MENU_" + alg.commandLineName()]
                 item = self.items[setting]
                 item.setData(d, Qt.EditRole)
@@ -264,6 +265,7 @@ class ConfigDialog(BASE, WIDGET):
 
     def accept(self):
         QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
+        qsettings = QSettings()
         for setting in self.items.keys():
             if setting.group != menusSettingsGroup or self.saveMenus:
                 if isinstance(setting.value, bool):
@@ -275,7 +277,7 @@ class ConfigDialog(BASE, WIDGET):
                         QMessageBox.warning(self, self.tr('Wrong value'),
                                             self.tr('Wrong value for parameter "%s":\n\n%s' % (setting.description, unicode(e))))
                         return
-                setting.save()
+                setting.save(qsettings)
         Processing.updateAlgsList()
         settingsWatcher.settingsChanged.emit()
         updateMenus()
@@ -345,6 +347,8 @@ class SettingDelegate(QStyledItemDelegate):
         setting = index.model().data(index, Qt.UserRole)
         if setting.valuetype == Setting.SELECTION:
             editor.setCurrentIndex(editor.findText(value))
+        elif setting.valuetype == Setting.INT or setting.valuetype == Setting.FLOAT:
+            editor.setValue(value)
         else:
             editor.setText(value)
 
